Pet Store — sphinxcontrib-openapi-test documentation

# Pet Store

Version 1.0.0

## Services

### pets

GET /pets

  List all pets

  List all pets - description

  DEPRECATED

  Query Parameters

    - limit (integer) – How many items to return at one time (max 100)

  Response Headers

    - x-next – A link to the next page of responses

  Status Codes

    - 200 OK – A paged array of pets See Pets

    - default – unexpected error See Error

  Example request:

      GET /pets?limit=1 HTTP/1.1
      Host: example.com

  Example response:

      HTTP/1.1 200 OK
      Content-Type: application/json

      [
          {
              "id": 1,
              "name": "string",
              "tag": "string"
          }
      ]

  Example response:

      HTTP/1.1 default -
      Content-Type: application/json

      {
          "code": 1,
          "message": "string"
      }

POST /pets

  Create a pet

  Status Codes

    - 201 Created – Null response

    - default – unexpected error See Error

  Example response:

      HTTP/1.1 default -
      Content-Type: application/json

      {
          "code": 1,
          "message": "string"
      }

GET /pets/{petId}

  Info for a specific pet

  Parameters

    - petId (string) – The id of the pet to retrieve

  Status Codes

    - 200 OK – Expected response to a valid request See Pets

    - default – unexpected error See Error

  Example request:

      GET /pets/{petId} HTTP/1.1
      Host: example.com

  Example response:

      HTTP/1.1 200 OK
      Content-Type: application/json

      [
          {
              "id": 1,
              "name": "string",
              "tag": "string"
          }
      ]

  Example response:

      HTTP/1.1 default -
      Content-Type: application/json

      {
          "code": 1,
          "message": "string"
      }

## Data Model

### Pet

Pet
Attribute | Type | Description | Mandatory
--- | --- | --- | ---
`id` | integer/int64 | Constraints: read only | Yes
`name` | string | DEPRECATED | Yes
`tag` | string | Constraints: write only DEPRECATED |

### Pets

Pets
Attribute | Type | Description | Mandatory
--- | --- | --- | ---
N/A | Array of Pet |  |

### Error

Error
Attribute | Type | Description | Mandatory
--- | --- | --- | ---
`code` | integer/int32 |  | Yes
`message` | string |  | Yes